Platforms
=========

This module contains platform-related functionality.

.. automodule:: financepype.platforms.platform
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: financepype.platforms.blockchain
    :members:
    :undoc-members:
    :show-inheritance:
